@keyframes swing {
  0% {
    transform: rotate(0deg);
  }
  10% {
    transform: rotate(10deg);
  }
  30% {
    transform: rotate(0deg);
  }
  40% {
    transform: rotate(-10deg);
  }
  50% {
    transform: rotate(0deg);
  }
  60% {
    transform: rotate(5deg);
  }
  70% {
    transform: rotate(0deg);
  }
  80% {
    transform: rotate(-5deg);
  }
  100% {
    transform: rotate(0deg);
  }
}

@keyframes sonar {
  0% {
    transform: scale(0.9);
    opacity: 1;
  }
  100% {
    transform: scale(2);
    opacity: 0;
  }
}

body {
  font-size: 0.9rem;
}

.page-wrapper .sidebar-wrapper,
.sidebar-wrapper .sidebar-brand > a,
.sidebar-wrapper .sidebar-options > a,
.sidebar-wrapper .sidebar-dropdown > a:after,
.sidebar-wrapper .sidebar-menu .sidebar-dropdown .sidebar-submenu li a:before,
.sidebar-wrapper ul li a i,
.page-wrapper .page-content,
.sidebar-wrapper .sidebar-search input.search-menu,
.sidebar-wrapper .sidebar-search .input-group-text,
.sidebar-wrapper .sidebar-menu ul li a,
.show-sidebar, #close-sidebar {
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

/*----------------page-wrapper----------------*/

.page-wrapper .theme {
  width: 40px;
  height: 40px;
  display: inline-block;
  border-radius: 4px;
  margin: 2px;
}

.page-wrapper .theme.chiller-theme {
  background: #1e2229;
}

/*----------------toggeled sidebar----------------*/

.page-wrapper.toggled .sidebar-wrapper {
  left: 0;
}

.page-wrapper.toggled-min .sidebar-wrapper {
  max-width: 83px;
  left: 0;
}


/*----------------show sidebar button----------------*/

.show-sidebar {
  cursor: pointer;
  font-size: 20px;
  position: absolute;
  top: 0;
  left: 55px;
  border-radius: 0 4px 4px 0;
  width: 35px;
  transition-delay: 0.3s;
  display: block;
  color: #bdbdbd;
}

@media (max-width: 960px){
    /* laptop-celular */
    .page-wrapper.toggled-min .sidebar-wrapper {
        max-width: 228px;
        display: none;
    }
    /* show-sidebar */
    .show-sidebar {
      cursor: pointer;
      font-size: 20px;
      position: absolute;
      top: 8px;
      left: 0;
      border-radius: 0 4px 4px 0;
      width: 35px;
      transition-delay: 0.3s;
      color: #bdbdbd;
    }
    .side-mobi {
      display: block;
    }
    .side-desk {
      display: none;
    }
    .sidebar-header-wrapper {
        background-color: #343a40;
        z-index: 1;
        display: block;
    }
}

@media screen and (min-width: 768px) {
  .page-wrapper.toggled .page-content {
    padding-left: 300px;
  }
  .sidebar-header-wrapper {
      background-color: transparent !important;
      z-index: -5;
      display: none;
  }
}
/*----------------sidebar-wrapper----------------*/

.sidebar-wrapper {
  width: 260px;
  height: 100%;
  max-height: 100%;
  position: fixed;
  top: 0;
  left: -300px;
  z-index: 1;
}

.sidebar-wrapper ul {
  list-style-type: none;
  padding: 0;
  margin: 0;
}

.sidebar-wrapper a {
  text-decoration: none;
}

/*----------------sidebar-content----------------*/

.sidebar-content {
  max-height: calc(100% - 30px);
  height: calc(100% - 30px);
  overflow-y: auto;
  position: relative;
}

.sidebar-content.desktop {
  overflow-y: hidden;
}

/*--------------------sidebar-brand----------------------*/

.sidebar-wrapper .sidebar-brand .text {
  padding: 8px 7px 8px 5px;
  display: flex;
  align-items: center;
}

.sidebar-wrapper .sidebar-brand > a .icon_small-block {
  display: block;
}

.sidebar-wrapper .sidebar-brand > a .icon_small-none {
  display: none;
}

.sidebar-wrapper .sidebar-brand > a .icon_large-block {
  display: block;
}

.sidebar-wrapper .sidebar-brand > a .icon_large-none {
  display: none;
}

.sidebar-wrapper .sidebar-brand {
  padding: 3px 10px 0 1px;
  display: flex;
  align-items: center;
}

.sidebar-wrapper .sidebar-brand > a {
  text-transform: uppercase;
  font-weight: bold;
  flex-grow: 1;
}

.sidebar-wrapper .sidebar-brand > a > span {
  padding: 8px 10px 8px 5px;
}

.sidebar-wrapper .sidebar-brand #close-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 55px;
}

.sidebar-wrapper .sidebar-brand .show-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 50px;
}

/* menu reduzido */
.page-wrapper.toggled-min .sidebar-wrapper .sidebar-brand {
  padding: 10px 0px;
  /*display: flex;*/
  align-items: center;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-brand > a > span {
  padding: 5px 0px 5px 0px;
  word-wrap: break-word;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-brand #close-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 150px;
  display: none;
}

.page-wrapper.toggled-min .sidebar-wrapper .show-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 150px;
}


/*--------------------sidebar-options----------------------*/

.sidebar-wrapper .sidebar-options {
  padding: 3px 10px 0 1px;
  /*display: flex;*/
  align-items: center;
  border-bottom: 1px solid #3a3f48;
}

.sidebar-wrapper .sidebar-options > ul .sidebar-link .sidebar-link-text  {
  color: #fff;
  text-transform: uppercase;
  font-weight: bold;
  flex-grow: 1;
}

.sidebar-wrapper .sidebar-options > ul .sidebar-link  {
  padding: 9px 12px 8px 16px;
}

.sidebar-wrapper .sidebar-options > ul .sidebar-link:hover  {
  background: none;
}

.sidebar-wrapper .sidebar-options > ul .sidebar-link:hover .sidebar-link-text,
.sidebar-wrapper .sidebar-options > ul .sidebar-link:hover .sidebar-link-icon {
  color: #4BCCD6;
}

.sidebar-wrapper .sidebar-options > ul .sidebar-link .sidebar-link-icon {
  color: #fff;
}

.sidebar-wrapper .sidebar-options #close-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 55px;
}

.sidebar-wrapper .sidebar-options .show-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 50px;
}

/* menu reduzido */
.page-wrapper.toggled-min .sidebar-wrapper .sidebar-options {
  padding: 10px 0px;
  align-items: center;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-options > ul .sidebar-link .sidebar-link-icon {
  display: inline-block;
  font-size: 21px;
  padding-left: 12px;
  color: #fff;

}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-options > ul .sidebar-link {
    padding: 9px 12px 8px 20px;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-options > ul .sidebar-link:hover .sidebar-link-icon {
  color: #4BCCD6;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-options > ul .sidebar-link .sidebar-link-text {
  display: none;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-options #close-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 150px;
  display: none;
}

.page-wrapper.toggled-min .sidebar-wrapper .show-sidebar {
  cursor: pointer;
  font-size: 20px;
  margin-left: 150px;
}

/*--------------------sidebar-header----------------------*/

.sidebar-wrapper .sidebar-header {
    padding: 20px 20px 100px;
    overflow: hidden;
}

.sidebar-wrapper .sidebar-header .user-pic {
  float: left;
  width: 60px;
  padding: 2px;
  border-radius: 12px;
  margin-right: 15px;
  overflow: hidden;
}

.sidebar-wrapper .sidebar-header .user-pic img {
  object-fit: cover;
  height: 100%;
  width: 100%;
  align: center;
}

.sidebar-wrapper .sidebar-header .user-info .user-role {
  font-size: 12px;
}

.sidebar-wrapper .sidebar-header .user-info .user-status {
  font-size: 11px;
}

.sidebar-wrapper .sidebar-header .user-info .user-status i {
  font-size: 8px;
  margin-right: 4px;
  color: #5cb85c;
}

/*-----------------------sidebar-search------------------------*/

.sidebar-wrapper .sidebar-search > div {
  padding: 10px 20px;
}

/*----------------------sidebar-menu-------------------------*/

.sidebar-wrapper .sidebar-menu {
  padding-bottom: 10px;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-menu .header-menu span {
  display: none;
}

.sidebar-wrapper .sidebar-menu .header-menu span {
    font-weight: bold;
    font-size: 15px;
    padding: 15px 20px 15px 20px;
    display: inline-block;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-menu ul li a span{
  display: none;
}

.sidebar-wrapper .sidebar-menu ul li a {
    display: inline-block;
    width: 93%;
    text-decoration: none;
    position: relative;
    padding: 7px 6px 13px 12px;
}

.sidebar-wrapper .sidebar-menu ul li a i {
  margin-right: 10px;
  font-size: 12px;
  width: 30px;
  height: 30px;
  line-height: 30px;
  text-align: center;
  border-radius: 4px;
}

/* menu reduzido */
.page-wrapper.toggled-min .sidebar-wrapper .sidebar-menu ul li a i {
    margin-right: 0;
    width: 54px;
    height: 43px;
    line-height: 44px;
    border-radius: 0;
    margin-left: 10px;
    font-size:17px;
}
/**/

.sidebar-wrapper .sidebar-menu ul li a:hover > i::before {
  display: inline-block;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-menu .sidebar-dropdown > a:after {
  display: none;
}

.sidebar-link .sidebar-link-label > span::before {
  display: inline-block;
}

.sidebar-link  > span:after {
  display: none;
}

.page-wrapper.toggled-min .sidebar-wrapper .sidebar-menu ul li a {
    display: inline-block;
    width: 93%;
    text-decoration: none;
    position: relative;
    padding: 2px 0 7px 5px;
}


.sidebar-wrapper .sidebar-menu .sidebar-dropdown > a:after {
  font-family: "Font Awesome 5 Free", serif;
  font-weight: 900;
  content: "\f105";
  font-style: normal;
  display: inline-block;
  font-variant: normal;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-align: center;
  background: 0 0;
  position: absolute;
  right: 13px;
  top: 15px;
}

.sidebar-wrapper .sidebar-menu .sidebar-dropdown .sidebar-submenu ul {
  padding: 5px 0;
}

.sidebar-wrapper .sidebar-menu .sidebar-dropdown .sidebar-submenu li {
  padding-left: 7px;
  font-size: 12px;
}

.sidebar-wrapper .sidebar-menu .sidebar-dropdown .sidebar-submenu li a:before {
  content: "\f111";
  font-family: "Font Awesome 5 Free", serif;
  font-weight: 400;
  font-style: normal;
  display: inline-block;
  text-align: center;
  text-decoration: none;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  margin-right: 10px;
  font-size: 8px;
}

.sidebar-wrapper .sidebar-menu ul li a span.label,
.sidebar-wrapper .sidebar-menu ul li a span.badge {
  float: right;
  margin-top: 8px;
  margin-left: 5px;
}

.sidebar-wrapper .sidebar-menu .sidebar-dropdown .sidebar-submenu li a .badge,
.sidebar-wrapper .sidebar-menu .sidebar-dropdown .sidebar-submenu li a .label {
  float: right;
  margin-top: 0;
}

.sidebar-wrapper .sidebar-menu .sidebar-submenu {
  display: none;
}

.sidebar-wrapper .sidebar-menu .sidebar-dropdown.active > a:after {
  transform: rotate(90deg);
  right: 13px;
}

/*--------------------------side-footer------------------------------*/

.sidebar-footer {
  position: absolute;
  width: 100%;
  bottom: 0;
  display: flex;
}

.sidebar-footer > a {
  flex-grow: 1;
  text-align: center;
  height: 30px;
  line-height: 30px;
  position: relative;
}

.sidebar-footer > a .notification {
  position: absolute;
  top: 0;
}

.badge-sonar {
  display: inline-block;
  background: #980303;
  border-radius: 50%;
  height: 8px;
  width: 8px;
  position: absolute;
  top: 0;
}

.badge-sonar:after {
  position: absolute;
  top: 0;
  left: 0;
  border: 2px solid #980303;
  opacity: 0;
  border-radius: 50%;
  width: 100%;
  height: 100%;
  animation: sonar 1.5s infinite;
}

/*--------------------------page-content-----------------------------*/

.page-wrapper .page-content {
  display: inline-block;
  width: 100%;
  padding-left: 0;
  padding-top: 20px;
}

.page-wrapper .page-content > div {
  padding: 20px 40px;
}

.page-wrapper .page-content {
  overflow-x: hidden;
}

/*------scroll bar---------------------*/

::-webkit-scrollbar {
  width: 5px;
  height: 7px;
}
::-webkit-scrollbar-button {
  width: 0;
  height: 0;
}
::-webkit-scrollbar-thumb {
  background: #525965;
  border: 0 none #ffffff;
  border-radius: 0;
}
::-webkit-scrollbar-thumb:hover {
  background: #525965;
}
::-webkit-scrollbar-thumb:active {
  background: #525965;
}
::-webkit-scrollbar-track {
  background: transparent;
  border: 0 none #ffffff;
  border-radius: 50px;
}
::-webkit-scrollbar-track:hover {
  background: transparent;
}
::-webkit-scrollbar-track:active {
  background: transparent;
}
::-webkit-scrollbar-corner {
  background: transparent;
}


/*-----------------------------chiller-theme-------------------------------------------------*/

.chiller-theme .sidebar-wrapper {
    background: #31353D;
}

.chiller-theme .sidebar-wrapper .sidebar-header,
.chiller-theme .sidebar-wrapper .sidebar-search,
.chiller-theme .sidebar-wrapper .sidebar-menu {
    border-top: 1px solid #3a3f48;
}

.chiller-theme .sidebar-wrapper .sidebar-search input.search-menu,
.chiller-theme .sidebar-wrapper .sidebar-search .input-group-text {
    border-color: transparent;
    box-shadow: none;
}

.chiller-theme .sidebar-wrapper .sidebar-header .user-info .user-role,
.chiller-theme .sidebar-wrapper .sidebar-header .user-info .user-status,
.chiller-theme .sidebar-wrapper .sidebar-search input.search-menu,
.chiller-theme .sidebar-wrapper .sidebar-search .input-group-text,
.chiller-theme .sidebar-wrapper .sidebar-brand>a,
.chiller-theme .sidebar-wrapper .sidebar-options>a,
.chiller-theme .sidebar-wrapper .sidebar-menu ul li a,
.chiller-theme .sidebar-footer>a {
    color: #ffffff;
}

.chiller-theme .sidebar-wrapper .sidebar-menu ul li:hover>a,
.chiller-theme .sidebar-wrapper .sidebar-menu .sidebar-dropdown.active>a,
.chiller-theme .sidebar-wrapper .sidebar-header .user-info,
.chiller-theme .sidebar-wrapper .sidebar-brand>a:hover,
.chiller-theme .sidebar-wrapper .sidebar-options>a:hover,
.chiller-theme .sidebar-footer>a:hover i {
    color: #4BCCD6;
}

.page-wrapper.chiller-theme.toggled #close-sidebar {
    color: #ffffff;
}

.page-wrapper.chiller-theme.toggled #close-sidebar:hover {
    color: #4BCCD6;
}

.chiller-theme .sidebar-wrapper ul li:hover a i,
.chiller-theme .sidebar-wrapper .sidebar-dropdown .sidebar-submenu li a:hover:before,
.chiller-theme .sidebar-wrapper .sidebar-search input.search-menu:focus+span,
.chiller-theme .sidebar-wrapper .sidebar-menu .sidebar-dropdown.active a i {
    color: #4BCCD6;
    #text-shadow:0 0 10px rgba(22, 199, 255, 0.5);
}

.chiller-theme .sidebar-wrapper .sidebar-menu ul li a i,
.chiller-theme .sidebar-wrapper .sidebar-menu .sidebar-dropdown div,
.chiller-theme .sidebar-wrapper .sidebar-search input.search-menu,
.chiller-theme .sidebar-wrapper .sidebar-search .input-group-text {
    background: #3a3f48;
}

.chiller-theme .sidebar-wrapper .sidebar-menu .header-menu span {
    color: #6c7b88;
}

.chiller-theme .sidebar-footer {
    background: #3a3f48;
    box-shadow: 0 -1px 5px #282c33;
    border-top: 1px solid #464a52;
}

.chiller-theme .sidebar-footer>a:first-child {
    border-left: none;
}

.chiller-theme .sidebar-footer>a:last-child {
    border-right: none;
}


.toggled-min .sidebar-wrapper .sidebar-footer a span {
    display: none;
}

.toggled-min .sidebar-wrapper .sidebar-footer a span {
    display: none;
}

.chiller-theme .sidebar-footer a:hover {
    color: #fff;
}

/* Button Menu */
.btn-bars {
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    user-select: none;
    border: 1px solid transparent;
}

.btn-arrow {
    text-align: right;
    white-space: nowrap;
    vertical-align: middle;
    user-select: none;
    border: 1px solid transparent;
}

/*.btn {
    text-align: right;
    white-space: nowrap;
    vertical-align: middle;
    user-select: none;
    border: 1px solid transparent;
}*/
.btn-sm, .btn-group-sm>.btn {
    padding: .25rem .5rem;
    line-height: 1.5;
}
.btn-dark.show-sidebar {
    color: #fff;
    background-color: #31353dc4;
    border-color: #31353dc4;
}
.btn-dark.show-sidebar:hover {
    color: #fff;
    background-color: #23272b;
    border-color: #1d2124;
}
/***********************************************************************************************************************/
/* CONTAINER */
/* correções layout */

@media (min-width: 960px){
    /* reduzido */
    body.menu-unpinned #container {
        padding-left: 85px;
    }

    /* aberto */
    body.menu-pinned #container {
        padding-left: 17.85714rem;
    }
}

@media (min-width: 960px){
    body.menu-unpinned table.helper {
        left: 105px;
        width: 87.3%;
    }
    body.menu-pinned table.helper {
        left: 270px;
        width: 70.09%;
    }
}

@media (min-width: 1024px){
    body.menu-unpinned table.helper {
        left: 105px;
        width: 87.8%;
    }
    body.menu-pinned table.helper {
        left: 19.3rem;
        width: 71.8%;
    }
}

@media (min-width: 1200px){
    body.menu-unpinned table.helper {
        left: 105px;
        width: 89.8%;
    }
    body.menu-pinned table.helper {
        left: 19.3rem;
        width: 76.2%;
    }
}

@media (min-width: 1300px){
    body.menu-unpinned table.helper {
        left: 105px;
        width: 91.2%;
    }
    body.menu-pinned table.helper {
        left: 19.3rem;
        width: 79.4%;
    }
}
@media (min-width: 1400px){
    body.menu-unpinned table.helper {
        left: 105px;
        width: calc(100% - 125px);
    }
    body.menu-pinned table.helper {
        left: 19.3rem;
        width: calc(100% - 290px);
    }
}

body.menu-unpinned .related-popup-back, .related-popup-back:visited, .related-popup-back:hover {
    left: 11.85714rem;
    z-index: 5;
    width: 6.14286rem;
}
body.menu-pinned .related-popup-back, .related-popup-back:visited, .related-popup-back:hover {
    left: 19.6rem;
    z-index: 5;
    width: 6.14286rem;
}
body.menu-unpinned .related-popup {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: -98px;
}
body.menu-pinned .related-popup {
    padding-left: 18.6rem;
}